==> haskell-test-framework-quickcheck2-0.3.0.5-289-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-quickcheck2
version:              0.3.0.5
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.5-3AjF6bO9HzPKJbxx0rLae4
key:                  test-framework-quickcheck2-0.3.0.5-3AjF6bO9HzPKJbxx0rLae4
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://haskell.github.io/test-framework/
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  da1e4e4def636fd5bad6cfae9899b289
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/test-framework-quickcheck2-0.3.0.5

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/test-framework-quickcheck2-0.3.0.5

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/test-framework-quickcheck2-0.3.0.5

hs-libraries:         HStest-framework-quickcheck2-0.3.0.5-3AjF6bO9HzPKJbxx0rLae4
depends:
    QuickCheck-2.14.2-5cPRTtrxXz46wA1XUCyvzI base-4.15.0.0
    extensible-exceptions-0.1.1.4-78NMIT9qofYFWl0e48Yw92
    random-1.2.0-DdpBoDDjQauFpQb1Ggrsga
    test-framework-0.8.2.0-D3l7ndGiWpNBsC8331h9ia

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-quickcheck2-0.3.0.5-296-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-quickcheck2
version:              0.3.0.5
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.5-AcDMe9qBlmZKK7TRcgrWbt
key:                  test-framework-quickcheck2-0.3.0.5-AcDMe9qBlmZKK7TRcgrWbt
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://haskell.github.io/test-framework/
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  3419ad147101ec45f8e3b608a056516e
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/test-framework-quickcheck2-0.3.0.5

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/test-framework-quickcheck2-0.3.0.5

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/test-framework-quickcheck2-0.3.0.5

hs-libraries:         HStest-framework-quickcheck2-0.3.0.5-AcDMe9qBlmZKK7TRcgrWbt
depends:
    QuickCheck-2.14.2-IrY4A8ma85dGplUSiagEJp base-4.15.0.0
    extensible-exceptions-0.1.1.4-78NMIT9qofYFWl0e48Yw92
    random-1.2.0-FfulI1BwpsjGO0LPW59p9g
    test-framework-0.8.2.0-I3YRpslA4rAJ7qbrsG22ZB

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
